isEncoderSupported method
Checks if the given encoder is supported on the current platform.
Implementation
Future<bool> isEncoderSupported(AudioEncoder encoder) {
return _safeCall(() => _platform.isEncoderSupported(_recorderId, encoder));
}
Checks if the given encoder is supported on the current platform.
Future<bool> isEncoderSupported(AudioEncoder encoder) {
return _safeCall(() => _platform.isEncoderSupported(_recorderId, encoder));
}